mysql.stmt.bind_out.Base_Out_Stream

Package mysql :: Package stmt :: Module bind_out :: Class Base_Out_Stream |
[hide private]
[frames] | no frames]

# Class Base_Out_Stream

     object --+
              |
    Output_Bind --+
                  |
                 Base_Out_Stream

Known Subclasses:
  Out_Blob, Out_Long_Blob, Out_Medium_Blob, Out_Tiny_Blob

Base class for streaming output.

The constructor takes the following arguments:

- `who`: The object on which to set the value.
- `what`: The attribute name to set on the object.
- `max_size`: The size of the buffer in bytes to use to fetch data. Defaults to 4000.
- `store_stream`: If True, will store a stream object (Output_Stream) which has a `read` method. Otherwise it stores the entire result as a string. Defaults to False.

Instance Methods | [hide private]
`` | __init__(...) x.__init__(...) initializes x; see x.__class__.__doc__ for signature
`` | __new__(T, S, ...) Returns a new object with type S, a subtype of T...
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables | [hide private]
`` | __pyx_vtable__ = `<PyCObject object at 0x852e920>`

Instance Variables | [hide private]
Inherited from `Output_Bind`: `error`, `is_null`, `length` Inherited from `Output_Bind` (private): `_buffer`, `_buffer_length`, `_buffer_type`, `_is_unsigned`, `_what`, `_who`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(...) (Constructor) |
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: Output_Bind.__init__

### __new__(T, S, ...) |
    Returns:
        a new object with type S, a subtype of T
Overrides: Output_Bind.__new__

Class Variable Details | [hide private]

    ### __pyx_vtable__ Value:
        <PyCObject object at 0x852e920>